﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Androids;
using RimWorld;
using UnityEngine;
using Verse;

namespace AndroidConversion
{
	// Token: 0x02000002 RID: 2
	public class AndroidConversionWindow : Window
	{
		// Token: 0x17000001 RID: 1
		// (get) Token: 0x06000001 RID: 1 RVA: 0x00002050 File Offset: 0x00000250
		public override Vector2 InitialSize
		{
			get
			{
				return new Vector2(898f, 608f);
			}
		}

		// Token: 0x06000002 RID: 2 RVA: 0x00002061 File Offset: 0x00000261
		public AndroidConversionWindow(Building_ConversionChamber caller)
		{
			this.androidConverter = caller;
			this.FindActiveMods();
			this.RefreshCosts();
		}

		// Token: 0x06000003 RID: 3 RVA: 0x000020A0 File Offset: 0x000002A0
		public override void DoWindowContents(Rect inRect)
		{
			Text.Font = GameFont.Medium;
			Pawn currentPawn = this.androidConverter.currentPawn;
			string text = string.Format("{0} - {1} ({2})", Translator.Translate("ConversionMenuTitle"), currentPawn.Name.ToStringShort, currentPawn.def.LabelCap);
			float num = Text.CalcHeight(text, inRect.width);
			Widgets.Label(new Rect(inRect.x, inRect.y, inRect.width, num), text);
			Rect location = new Rect(0f, num + 10f, 268f, inRect.height - (num + 10f));
			Rect location2 = new Rect(inRect.width - 268f, num + 10f, 268f, inRect.height - (num + 10f));
			float x = (inRect.width - AndroidConversionWindow.PawnPortraitSize.x) / 2f;
			Rect location3 = new Rect(x, num + 10f, AndroidConversionWindow.PawnPortraitSize.x, AndroidConversionWindow.PawnPortraitSize.y);
			Rect location4 = new Rect(location.width + 20f, location3.y + location3.height + 20f, inRect.width - (location2.width + 20f) * 2f, 58f);
			Rect location5 = new Rect(location.width + 20f, location4.y + location4.height + 20f, location4.width, 32f);
			this.DisplayMods(true, location, ref this.modLeftScrollPosition);
			this.DisplayMods(false, location2, ref this.modRightScrollPosition);
			this.DisplayPawn(location3);
			this.DisplayCost(location4);
			this.DisplayButtons(location5);
			Text.Anchor = TextAnchor.UpperLeft;
		}

		// Token: 0x06000004 RID: 4 RVA: 0x00002270 File Offset: 0x00000470
		public void DisplayPawn(Rect location)
		{
			Pawn currentPawn = this.androidConverter.currentPawn;
			GUI.DrawTexture(location, PortraitsCache.Get(currentPawn, AndroidConversionWindow.PawnPortraitSize, Rot4.South, default(Vector3), 1f, true, true, true, true, null, null, false));
		}

		// Token: 0x06000005 RID: 5 RVA: 0x000022BC File Offset: 0x000004BC
		public void DisplayMods(bool physical, Rect location, ref Vector2 scrollPos)
		{
			float num = 32f;
			float num2 = num + 35f;
			float width = location.width;
			float height = 32f;
			float num3 = 0f;
			Rect modSize = new Rect(0f, 0f, (float)AndroidCustomizationTweaks.upgradeBaseSize, (float)AndroidCustomizationTweaks.upgradeBaseSize);
			int num4 = (int)Math.Floor((double)(width / modSize.width));
			List<AndroidModGroupDef> list = new List<AndroidModGroupDef>();
			foreach (AndroidModGroupDef androidModGroupDef in DefDatabase<AndroidModGroupDef>.AllDefs)
			{
				if (androidModGroupDef.physical == physical)
				{
					num3 += androidModGroupDef.calculateNeededHeight(modSize, width);
					num3 += 52f;
					list.Add(androidModGroupDef);
				}
			}
			Rect rect = new Rect(location.x, num, width, height);
			Rect rect2 = new Rect(location.x, num2, width, num3);
			Rect rect3 = new Rect(location.x, num2, width, location.height);
			Text.Font = GameFont.Medium;
			Text.Anchor = TextAnchor.MiddleCenter;
			if (physical)
			{
				Widgets.Label(rect, Translator.Translate("AndroidPhysicsMods"));
			}
			else
			{
				Widgets.Label(rect, Translator.Translate("AndroidMentalMods"));
			}
			Widgets.DrawLineHorizontal(rect.x, rect.y + 32f, rect.width);
			float num5 = num2;
			Text.Font = GameFont.Small;
			Text.Anchor = TextAnchor.UpperLeft;
			Widgets.BeginScrollView(rect3, ref scrollPos, rect2, true);
			foreach (AndroidModGroupDef androidModGroupDef2 in from modGroup in list.AsEnumerable<AndroidModGroupDef>()
															   orderby modGroup.orderID
															   select modGroup)
			{
				Rect rect4 = new Rect(rect);
				rect4.y = num5;
				rect4.height = 22f;
				num5 += 30f;
				Text.Anchor = TextAnchor.MiddleCenter;
				Widgets.DrawTitleBG(rect4);
				Widgets.Label(rect4, androidModGroupDef2.label);
				Widgets.DrawLineHorizontal(rect4.x, rect4.y + 22f, rect4.width);
				Text.Anchor = TextAnchor.UpperLeft;
				androidModGroupDef2.calculateNeededHeight(modSize, width);
				int num6 = 0;
				using (IEnumerator<AndroidModDef> enumerator2 = androidModGroupDef2.Upgrades.OrderBy((AndroidModDef upgradeSubGroup) => upgradeSubGroup.orderID).GetEnumerator())
				{
					while (enumerator2.MoveNext())
					{
						AndroidModDef modCurrent = enumerator2.Current;
						if (modCurrent.enabled)
						{
							if (num6 >= num4)
							{
								num6 = 0;
								num5 += modSize.height;
							}
							Rect rect5 = new Rect(rect.x + modSize.width * (float)num6, num5, modSize.width, modSize.height);
							if (Mouse.IsOver(rect5))
							{
								StringBuilder stringBuilder = new StringBuilder();
								stringBuilder.AppendLine(modCurrent.label);
								stringBuilder.AppendLine();
								stringBuilder.AppendLine(modCurrent.description);
								stringBuilder.AppendLine();
								//if (modCurrent.hediffToApply != null && modCurrent.hediffToApply.ConcreteExample != null)
								//{
								//	stringBuilder.AppendLine(GenText.TrimEndNewlines(modCurrent.hediffToApply.ConcreteExample.TipStringExtra));
								//	stringBuilder.AppendLine();
								//}
								if (modCurrent.newBodyType != null)
								{
									stringBuilder.AppendLine(Translator.Translate("AndroidCustomizationChangeBodyType"));
									stringBuilder.AppendLine();
								}
								if (modCurrent.changeSkinColor)
								{
									stringBuilder.AppendLine(Translator.Translate("AndroidCustomizationChangeSkinColor"));
									stringBuilder.AppendLine();
								}
								stringBuilder.AppendLine(Translator.Translate("AndroidCustomizationTimeCost") + ": " + GenDate.ToStringTicksToPeriodVerbose(modCurrent.extraPrintingTime, true, true));
								if (modCurrent.requiredResearch != null && !modCurrent.requiredResearch.IsFinished)
								{
									stringBuilder.AppendLine();
									stringBuilder.AppendLine(Translator.Translate("AndroidCustomizationRequiredResearch") + ": " + modCurrent.requiredResearch.LabelCap);
								}
								TooltipHandler.TipRegion(rect5, stringBuilder.ToString());
							}
							bool flag = true;
							if (modCurrent.requiredResearch != null && !modCurrent.requiredResearch.IsFinished)
							{
								flag = false;
							}
							if (flag)
							{
								flag = !GenCollection.Any<ModCommand>(this.appliedUpgradeCommands, delegate (ModCommand appUpgrade)
								{
									bool result;
									if (appUpgrade.def != modCurrent)
									{
										if (appUpgrade.isActive && appUpgrade.removing)
										{
											result = false;
										}
										else
										{
											result = GenCollection.Any<string>(appUpgrade.def.exclusivityGroups, (string group) => modCurrent.exclusivityGroups.Contains(group));
										}
									}
									else
									{
										result = false;
									}
									return result;
								});
							}
							if (!flag)
							{
								Widgets.DrawRectFast(rect5, Color.red, null);
							}
							else if (GenCollection.Any<ModCommand>(this.appliedUpgradeCommands, (ModCommand modCommand) => modCommand.def == modCurrent))
							{
								Widgets.DrawRectFast(rect5, Color.white, null);
							}
							if (modCurrent.iconTexturePath != null)
							{
								Widgets.DrawTextureFitted(GenUI.ContractedBy(rect5, 3f), ContentFinder<Texture2D>.Get(modCurrent.iconTexturePath, true), 1f);
							}
							Widgets.DrawHighlightIfMouseover(rect5);
							ModCommand modCommand2 = this.appliedUpgradeCommands.FirstOrDefault((ModCommand ModCommand) => ModCommand.def == modCurrent);
							if (flag && Widgets.ButtonInvisible(rect5, true))
							{
								if (modCommand2 != null)
								{
									if (modCommand2.isActive)
									{
										modCommand2.removing = !modCommand2.removing;
									}
									else
									{
										this.appliedUpgradeCommands.Remove(modCommand2);
									}
								}
								else
								{
									ModCommand item = ModMaker.Make(modCurrent);
									this.appliedUpgradeCommands.Add(item);
								}
								this.RefreshCosts();
							}
							num6++;
						}
					}
				}
				num5 += modSize.height;
			}
			Widgets.EndScrollView();
		}

		// Token: 0x06000006 RID: 6 RVA: 0x000028E4 File Offset: 0x00000AE4
		public void DisplayCost(Rect location)
		{
			float x = location.x;
			float num = location.y;
			Text.Anchor = TextAnchor.MiddleLeft;
			Text.Font = GameFont.Medium;
			Rect rect = new Rect(x, num, 256f, 32f);
			Widgets.DrawTitleBG(rect);
			Widgets.Label(GenUI.ContractedBy(rect, 2f), Translator.Translate("AndroidConversionCostLabel"));
			num += rect.height;
			int num2 = 0;
			Text.Font = 0;
			Text.Anchor = TextAnchor.LowerLeft;
			Rect rect2 = new Rect(x + 3f, num, 26f, 26f);
			Widgets.DrawTextureFitted(rect2, ContentFinder<Texture2D>.Get("UI/TimeControls/TimeSpeedButton_Superfast", true), 1f);
			TooltipHandler.TipRegion(rect2, Translator.Translate("AndroidConversionTimeCost") + ": " + GenDate.ToStringTicksToPeriodVerbose(this.androidConverter.tickToMod + this.finalConversionTimeCost, true, true));
			Widgets.DrawHighlightIfMouseover(rect2);
			Widgets.Label(GenUI.ExpandedBy(rect2, 8f), GenDate.ToStringTicksToPeriodVerbose(this.androidConverter.tickToMod + this.finalConversionTimeCost, true, true) ?? "");
			num2++;
			Text.Anchor = TextAnchor.LowerRight;
			foreach (ThingOrderRequest thingOrderRequest in this.finalConversionItemCost)
			{
				Rect rect3 = new Rect(x + 3f + (float)num2 * 32f, num, 26f, 26f);
				if (thingOrderRequest.nutrition)
				{
					Widgets.DefIcon(rect3, RimWorld.ThingDefOf.Meat_Human, null, 1f, null, false, null);
					TooltipHandler.TipRegion(rect3, Translator.Translate("AndroidNutrition"));
				}
				else
				{
					Widgets.DefIcon(rect3, thingOrderRequest.thingDef, null, 1f, null, false, null);
					TooltipHandler.TipRegion(rect3, thingOrderRequest.thingDef.LabelCap);
				}
				Widgets.DrawHighlightIfMouseover(rect3);
				Widgets.Label(rect3, thingOrderRequest.amount.ToString() ?? "");
				num2++;
			}
		}

		// Token: 0x06000007 RID: 7 RVA: 0x00002B0C File Offset: 0x00000D0C
		public void DisplayButtons(Rect location)
		{
			Rect rect = new Rect(location.x, location.y, location.width, 32f);
			Rect rect2 = new Rect(location.x, location.y + 32f + 20f, location.width, 32f);
			Text.Font = GameFont.Medium;
			if (Widgets.ButtonText(rect, Translator.Translate("AndroidConversionStart"), true, true, true))
			{
				this.androidConverter.savedChanges = this.appliedUpgradeCommands;
				this.StartConversion();
				this.Close(true);
			}
			if (Widgets.ButtonText(rect2, Translator.Translate("AndroidConversionCancel"), true, true, true))
			{
				this.Close(true);
			}
		}

		// Token: 0x06000008 RID: 8 RVA: 0x00002BC4 File Offset: 0x00000DC4
		private void FindActiveMods()
		{
			Pawn currentPawn = this.androidConverter.currentPawn;
			foreach (AndroidModGroupDef androidModGroupDef in DefDatabase<AndroidModGroupDef>.AllDefs)
			{
				foreach (AndroidModDef def in from upgradeSubGroup in androidModGroupDef.Upgrades
											  orderby upgradeSubGroup.orderID
											  select upgradeSubGroup)
				{
					ModCommand modCommand = ModMaker.Make(def);
					if (modCommand.Active(currentPawn))
					{
						modCommand.isActive = true;
						this.appliedUpgradeCommands.Add(modCommand);
					}
				}
			}
		}

		// Token: 0x06000009 RID: 9 RVA: 0x00002C90 File Offset: 0x00000E90
		public void RefreshCosts()
		{
			this.finalConversionItemCost.Clear();
			this.finalConversionTimeCost = 0;
			if (!this.androidConverter.IsPawnAndroid())
			{
				PawnConversionProperites conversionProperties = this.androidConverter.conversionProperties;
				foreach (ThingOrderRequest thingOrderRequest in conversionProperties.costList)
				{
					ThingOrderRequest thingOrderRequest2 = new ThingOrderRequest();
					thingOrderRequest2.amount = thingOrderRequest.amount;
					thingOrderRequest2.nutrition = thingOrderRequest.nutrition;
					thingOrderRequest2.thingDef = thingOrderRequest.thingDef;
					this.finalConversionItemCost.Add(thingOrderRequest2);
				}
				this.finalConversionTimeCost += conversionProperties.ticksToConvert;
			}
			List<ThingDef> list = new List<ThingDef>();
			foreach (ModCommand modCommand in this.appliedUpgradeCommands)
			{
				if (!modCommand.isActive)
				{
					using (List<ThingOrderRequest>.Enumerator enumerator3 = modCommand.def.costList.GetEnumerator())
					{
						while (enumerator3.MoveNext())
						{
							ThingOrderRequest costToApply = enumerator3.Current;
							ThingOrderRequest thingOrderRequest3 = this.finalConversionItemCost.FirstOrDefault((ThingOrderRequest finalCost) => finalCost.thingDef == costToApply.thingDef || (finalCost.nutrition && costToApply.nutrition));
							if (thingOrderRequest3 != null)
							{
								thingOrderRequest3.amount += costToApply.amount;
							}
							else
							{
								thingOrderRequest3 = new ThingOrderRequest();
								thingOrderRequest3.amount = costToApply.amount;
								thingOrderRequest3.nutrition = costToApply.nutrition;
								thingOrderRequest3.thingDef = costToApply.thingDef;
								this.finalConversionItemCost.Add(thingOrderRequest3);
							}
						}
					}
					list.AddRange(modCommand.def.costsNotAffectedByBodySize);
					this.finalConversionTimeCost += modCommand.def.extraPrintingTime;
				}
				else if (modCommand.removing)
				{
					this.finalConversionTimeCost += modCommand.def.removalPrintingTime;
				}
			}
			if (list.Count > 0)
			{
				list = new List<ThingDef>(list.Distinct<ThingDef>());
			}
			//foreach (ThingOrderRequest thingOrderRequest4 in this.finalConversionItemCost)
			//{
			//	if (!list.Contains(thingOrderRequest4.thingDef))
			//	{
			//		thingOrderRequest4.amount = (float)Math.Ceiling((double)(thingOrderRequest4.amount * this.androidConverter.currentPawn.def.race.baseBodySize));
			//	}
			//}
		}

		// Token: 0x0600000A RID: 10 RVA: 0x00002F98 File Offset: 0x00001198
		public void StartConversion()
		{
			this.androidConverter.orderProcessor.requestedItems = this.finalConversionItemCost;
			this.androidConverter.remainingTickTracker = (this.androidConverter.tickToMod = this.finalConversionTimeCost);
			this.androidConverter.ChamberStatus = ModdingStatus.Filling;
		}

		// Token: 0x04000001 RID: 1
		public Building_ConversionChamber androidConverter;

		// Token: 0x04000002 RID: 2
		public List<ThingOrderRequest> finalConversionItemCost = new List<ThingOrderRequest>();

		// Token: 0x04000003 RID: 3
		public int finalConversionTimeCost;

		// Token: 0x04000004 RID: 4
		public Vector2 modLeftScrollPosition;

		// Token: 0x04000005 RID: 5
		public Vector2 modRightScrollPosition;

		// Token: 0x04000006 RID: 6
		public List<ModCommand> appliedUpgradeCommands = new List<ModCommand>();

		// Token: 0x04000007 RID: 7
		public List<Trait> originalTraits = new List<Trait>();

		// Token: 0x04000008 RID: 8
		public static readonly float upgradesOffset = 640f;

		// Token: 0x04000009 RID: 9
		private static readonly Vector2 PawnPortraitSize = new Vector2(100f, 140f);
	}
}
