﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Androids;
using RimWorld;
using UnityEngine;
using Verse;
using Verse.AI;
using Verse.Sound;

namespace AndroidConversion
{
	// Token: 0x02000012 RID: 18
	public class Building_ConversionChamber : Building, IThingHolder, IStoreSettingsParent
	{
        public void Notify_SettingsChanged()
		{

		}

        // Token: 0x06000036 RID: 54 RVA: 0x00003920 File Offset: 0x00001B20
        public Building_ConversionChamber()
		{
			this.innerContainer = new ThingOwner<Thing>(this, false, LookMode.Deep);
			this.ingredients = new ThingOwner<Thing>();
			this._power = base.GetComp<CompPowerTrader>();
		}

		// Token: 0x06000037 RID: 55 RVA: 0x0000396E File Offset: 0x00001B6E
		public ThingOwner GetDirectlyHeldThings()
		{
			return this.ingredients;
		}

		// Token: 0x06000038 RID: 56 RVA: 0x00003976 File Offset: 0x00001B76
		public void GetChildHolders(List<IThingHolder> outChildren)
		{
			ThingOwnerUtility.AppendThingHoldersFromThings(outChildren, this.GetDirectlyHeldThings());
		}

		// Token: 0x17000005 RID: 5
		// (get) Token: 0x06000039 RID: 57 RVA: 0x00003984 File Offset: 0x00001B84
		public bool HasAnyContents
		{
			get
			{
				return this.innerContainer.Count > 0;
			}
		}

		// Token: 0x0600003A RID: 58 RVA: 0x00003994 File Offset: 0x00001B94
		public void EjectContents()
		{
			this.innerContainer.TryDropAll(this.InteractionCell, base.Map, ThingPlaceMode.Near, null, null, true);
			this.contentsKnown = true;
			this.Notify_PawnEntered();
		}

		// Token: 0x17000006 RID: 6
		// (get) Token: 0x0600003B RID: 59 RVA: 0x000039BF File Offset: 0x00001BBF
		public bool CanOpen
		{
			get
			{
				return this.HasAnyContents;
			}
		}

		// Token: 0x0600003C RID: 60 RVA: 0x000039C7 File Offset: 0x00001BC7
		public void Open()
		{
			if (!this.HasAnyContents)
			{
				return;
			}
			this.EjectContents();
			this.tickToMod = 0;
		}

		// Token: 0x0600003D RID: 61 RVA: 0x000039DF File Offset: 0x00001BDF
		public virtual bool Accepts(Thing thing)
		{
			return this.innerContainer.CanAcceptAnyOf(thing, true);
		}

		// Token: 0x0600003E RID: 62 RVA: 0x000039F0 File Offset: 0x00001BF0
		public virtual bool TryAcceptThing(Thing thing, bool allowSpecialEffects = true)
		{
			Pawn pawn = thing as Pawn;
			if (pawn == null)
			{
				Log.Error(string.Concat(new string[]
				{
					base.ThingID,
					" accepted non pawn ",
					pawn.ThingID,
					"/",
					pawn.GetType().Name,
					"! this should never happen"
				}));
				return false;
			}
			if (this.innerContainer.TryAdd(thing, true))
			{
				if (thing.Faction != null && thing.Faction.IsPlayer)
				{
					this.contentsKnown = true;
				}
				this.ChamberStatus = ModdingStatus.Idle;
				return true;
			}
			Log.Warning("Could not add to container");
			return false;
		}

		// Token: 0x0600003F RID: 63 RVA: 0x00003A90 File Offset: 0x00001C90
		public StorageSettings GetStoreSettings()
		{
			return this.inputSettings;
		}

		// Token: 0x06000040 RID: 64 RVA: 0x00003A98 File Offset: 0x00001C98
		public StorageSettings GetParentStoreSettings()
		{
			return this.def.building.fixedStorageSettings;
		}

		// Token: 0x17000007 RID: 7
		// (get) Token: 0x06000041 RID: 65 RVA: 0x00003AAA File Offset: 0x00001CAA
		public bool StorageTabVisible
		{
			get
			{
				return true;
			}
		}

		// Token: 0x17000008 RID: 8
		// (get) Token: 0x06000042 RID: 66 RVA: 0x00003AAD File Offset: 0x00001CAD
		public Thing ContainedThing
		{
			get
			{
				if (this.innerContainer.Count != 0)
				{
					return this.innerContainer[0];
				}
				return null;
			}
		}

		// Token: 0x17000009 RID: 9
		// (get) Token: 0x06000043 RID: 67 RVA: 0x00003ACC File Offset: 0x00001CCC
		public override Graphic Graphic
		{
			get
			{
				if (this.conversionProperties.hidePawnGraphic == null)
				{
					return base.Graphic;
				}
				if (!this.HasAnyContents)
				{
					return base.Graphic;
				}
				if (this.cachedGraphicFull == null)
				{
					this.cachedGraphicFull = this.conversionProperties.hidePawnGraphic.GraphicColoredFor(this);
				}
				return this.cachedGraphicFull;
			}
		}

		// Token: 0x06000044 RID: 68 RVA: 0x00003B21 File Offset: 0x00001D21
		public void Notify_PawnEntered()
		{
			base.Map.mapDrawer.MapMeshDirty(base.Position, MapMeshFlag.None);//TODO
		}

		// Token: 0x1700000A RID: 10
		// (get) Token: 0x06000045 RID: 69 RVA: 0x00003B3A File Offset: 0x00001D3A
		private CompPowerTrader PowerCompTrader
		{
			get
			{
				return this._power;
			}
		}

		// Token: 0x06000046 RID: 70 RVA: 0x00003B44 File Offset: 0x00001D44
		public void AdjustPowerNeed()
		{
			if (this.flickableComp != null && (this.flickableComp == null || !this.flickableComp.SwitchIsOn))
			{
				this.powerComp.PowerOutput = 0f;
				return;
			}
			if (this.ChamberStatus == ModdingStatus.Modding)
			{
				this.powerComp.PowerOutput = -this.powerComp.Props.PowerConsumption;
				return;
			}
			this.powerComp.PowerOutput = -this.powerComp.Props.PowerConsumption * 0.1f;
		}

		// Token: 0x06000047 RID: 71 RVA: 0x00003BC7 File Offset: 0x00001DC7
		private void ResetProcess()
		{
			this.ChamberStatus = ModdingStatus.WaitingForPawn;
			this.orderProcessor.requestedItems.Clear();
		}

		// Token: 0x06000048 RID: 72 RVA: 0x00003BE0 File Offset: 0x00001DE0
		public bool IsPawnAndroid()
		{
			return RaceUtility.IsAndroid(this.currentPawn);
		}

		// Token: 0x06000049 RID: 73 RVA: 0x00003BED File Offset: 0x00001DED
		public void InitiatePawnModing()
		{
			Find.WindowStack.Add(new AndroidConversionWindow(this));
		}

		// Token: 0x0600004A RID: 74 RVA: 0x00003BFF File Offset: 0x00001DFF
		public void EjectPawn()
		{
			this.ingredients.TryDropAll(this.InteractionCell, base.Map, ThingPlaceMode.Near, null, null, true);
			this.Open();
			this.ResetProcess();
		}

		// Token: 0x0600004B RID: 75 RVA: 0x00003C2C File Offset: 0x00001E2C
		public void CompleteConversion()
		{
			if (!this.IsPawnAndroid())
			{
				AndroidUtility.Androidify(this.currentPawn);
				LifeStageAge lifeStageAge = this.currentPawn.RaceProps.lifeStageAges[this.currentPawn.ageTracker.CurLifeStageIndex];
				if (lifeStageAge != null)
				{
					long num = (long)Math.Ceiling((double)lifeStageAge.minAge) * 3600000L;
					this.currentPawn.ageTracker.AgeBiologicalTicks = num;
					this.currentPawn.ageTracker.AgeChronologicalTicks = num;
				}
				else
				{
					long num2 = (long)(this.currentPawn.RaceProps.lifeExpectancy * 3600000f * 0.2f);
					this.currentPawn.ageTracker.AgeBiologicalTicks = num2;
					this.currentPawn.ageTracker.AgeChronologicalTicks = num2;
				}
			}
			foreach (ModCommand modCommand in this.savedChanges)
			{
				if (modCommand.isActive)
				{
					if (modCommand.removing)
					{
						modCommand.Remove(this.currentPawn);
					}
				}
				else
				{
					modCommand.Apply(this.currentPawn);
				}
			}
			this.Open();
			this.ResetProcess();
		}

		// Token: 0x0600004C RID: 76 RVA: 0x00003D70 File Offset: 0x00001F70
		public override IEnumerable<Gizmo> GetGizmos()
		{
			List<Gizmo> list = new List<Gizmo>(base.GetGizmos());
			if (this.ChamberStatus == ModdingStatus.Idle)
			{
				list.Insert(0, new Gizmo_StartMod(this));
				list.Insert(0, new Gizmo_AbortMod(this));
			}
			else if (this.ChamberStatus == ModdingStatus.Filling)
			{
				list.Insert(0, new Gizmo_AbortMod(this));
			}
			if (DebugSettings.godMode && (this.ChamberStatus == ModdingStatus.Filling || this.ChamberStatus == ModdingStatus.Modding))
			{
				list.Insert(0, new Command_Action
				{
					defaultLabel = "DEBUG: Finish modding.",
					defaultDesc = "Finishes modding the pawn.",
					action = delegate()
					{
						this.ChamberStatus = ModdingStatus.Finished;
					}
				});
			}
			return list;
		}

		// Token: 0x0600004D RID: 77 RVA: 0x00003E14 File Offset: 0x00002014
		public bool CanEnter(Pawn testPawn)
		{
			string pawnRaceName = testPawn.kindDef.race.defName;
			return (!(pawnRaceName != "Human") || RaceUtility.AlienRaceKinds.Any((PawnKindDef kind) => kind.race.defName == pawnRaceName)) && this.Accepts(testPawn);
		}

		// Token: 0x0600004E RID: 78 RVA: 0x00003E75 File Offset: 0x00002075
		public override IEnumerable<FloatMenuOption> GetFloatMenuOptions(Pawn myPawn)
		{
			if (QuestUtility.IsQuestLodger(myPawn))
			{
				FloatMenuOption floatMenuOption = new FloatMenuOption(TranslatorFormattedStringExtensions.Translate("CannotUseReason", Translator.Translate("CryptosleepCasketGuestsNotAllowed")), null, MenuOptionPriority.Default, null, null, 0f, null, null, true, 0);
				yield return floatMenuOption;
				yield break;
			}
			foreach (FloatMenuOption floatMenuOption2 in base.GetFloatMenuOptions(myPawn))
			{
				yield return floatMenuOption2;
			}
			if (this.innerContainer.Count == 0)
			{
				if (!ReachabilityUtility.CanReach(myPawn, this, PathEndMode.InteractionCell, Danger.Deadly, false, false, 0))
				{
					FloatMenuOption floatMenuOption3 = new FloatMenuOption(Translator.Translate("CannotUseNoPath"), null, MenuOptionPriority.Default, null, null, 0f, null, null, true, 0);
					yield return floatMenuOption3;
				}
				else if (!this.CanEnter(myPawn))
				{
					FloatMenuOption floatMenuOption4 = new FloatMenuOption(Translator.Translate("CannotBeConverted"), null, MenuOptionPriority.Default, null, null, 0f, null, null, true, 0);
					yield return floatMenuOption4;
				}
				else
				{
					JobDef jobDef = JobDefOf.DekEnterConversionChamber;
					string text = Translator.Translate("EnterConversionChamber");
					Action action = delegate()
					{
						Job job = JobMaker.MakeJob(jobDef, this);
						myPawn.jobs.TryTakeOrderedJob(job, new JobTag?(0), false);
					};
					yield return FloatMenuUtility.DecoratePrioritizedTask(new FloatMenuOption(text, action, MenuOptionPriority.Default, null, null, 0f, null, null, true, 0), myPawn, this, "ReservedBy");
				}
			}
			yield break;
		}

		// Token: 0x0600004F RID: 79 RVA: 0x00003E8C File Offset: 0x0000208C
		public override void SpawnSetup(Map map, bool respawningAfterLoad)
		{
			base.SpawnSetup(map, respawningAfterLoad);
			this.powerComp = base.GetComp<CompPowerTrader>();
			this.flickableComp = base.GetComp<CompFlickable>();
			if (this.inputSettings == null)
			{
				this.inputSettings = new StorageSettings(this);
				if (this.def.building.defaultStorageSettings != null)
				{
					this.inputSettings.CopyFrom(this.def.building.defaultStorageSettings);
				}
			}
			this.conversionProperties = this.def.GetModExtension<PawnConversionProperites>();
			if (!respawningAfterLoad)
			{
				if (this.conversionProperties == null)
				{
					this.conversionProperties = new PawnConversionProperites();
				}
				this.orderProcessor = new ThingOrderProcessor(this.ingredients, this.inputSettings);
			}
			this.AdjustPowerNeed();
		}

		// Token: 0x06000050 RID: 80 RVA: 0x00003F44 File Offset: 0x00002144
		public override void PostMake()
		{
			base.PostMake();
			this.inputSettings = new StorageSettings(this);
			if (this.def.building.defaultStorageSettings != null)
			{
				this.inputSettings.CopyFrom(this.def.building.defaultStorageSettings);
			}
		}

		// Token: 0x06000051 RID: 81 RVA: 0x00003F94 File Offset: 0x00002194
		public override void ExposeData()
		{
			base.ExposeData();
			Scribe_Deep.Look<ThingOwner<Thing>>(ref this.ingredients, "ingredients", Array.Empty<object>());
			Scribe_Values.Look<ModdingStatus>(ref this.ChamberStatus, "printerStatus", ModdingStatus.Idle, false);
			Scribe_Values.Look<int>(ref this.remainingTickTracker, "printingTicksLeft", 0, false);
			Scribe_Values.Look<int>(ref this.nextResourceTick, "nextResourceTick", 0, false);
			Scribe_Deep.Look<StorageSettings>(ref this.inputSettings, "inputSettings", Array.Empty<object>());
			Scribe_Deep.Look<ThingOrderProcessor>(ref this.orderProcessor, "orderProcessor", new object[]
			{
				this.ingredients,
				this.inputSettings
			});
			Scribe_Values.Look<int>(ref this.tickToMod, "totaltimeCost", 0, false);
			Scribe_Deep.Look<ThingOwner>(ref this.innerContainer, "innerContainer", new object[]
			{
				this
			});
			Scribe_Values.Look<bool>(ref this.contentsKnown, "contentsKnown", false, false);
			Scribe_Collections.Look<ModCommand>(ref this.savedChanges, "savedChanges", LookMode.Deep, Array.Empty<object>());
		}

		// Token: 0x06000052 RID: 82 RVA: 0x00004083 File Offset: 0x00002283
		public override void Destroy(DestroyMode mode = 0)
		{
			if (mode > 0)
			{
				this.ingredients.TryDropAll(base.PositionHeld, base.MapHeld, ThingPlaceMode.Near, null, null, true);
			}
			base.Destroy(mode);
		}

		// Token: 0x06000053 RID: 83 RVA: 0x000040B0 File Offset: 0x000022B0
		public override string GetInspectString()
		{
			string result;
			if (base.ParentHolder != null && !(base.ParentHolder is Map))
			{
				result = base.GetInspectString();
			}
			else
			{
				StringBuilder stringBuilder = new StringBuilder(base.GetInspectString());
				stringBuilder.AppendLine();
				StringBuilder stringBuilder2 = stringBuilder;
				string text = "AndroidModdingStatus";
				string str = "AndroidModdingStatusEnum";
				int chamberStatus = (int)this.ChamberStatus;
				stringBuilder2.AppendLine(TranslatorFormattedStringExtensions.Translate(text, Translator.Translate(str + chamberStatus.ToString())));
				if (this.ChamberStatus == ModdingStatus.Modding)
				{
					stringBuilder.AppendLine(TranslatorFormattedStringExtensions.Translate("AndroidModdingProgress", GenText.ToStringPercent(((float)this.tickToMod - (float)this.remainingTickTracker) / (float)this.tickToMod)));
				}
				if (this.ChamberStatus == ModdingStatus.Filling)
				{
					bool flag = true;
					stringBuilder.Append(this.FormatIngredientCosts(out flag, this.orderProcessor.requestedItems, true));
					if (!flag)
					{
						stringBuilder.AppendLine();
					}
				}
				if (this.ingredients.Count > 0)
				{
					stringBuilder.Append(Translator.Translate("AndroidPrinterMaterials") + " ");
				}
				foreach (Thing thing in this.ingredients)
				{
					stringBuilder.Append(thing.LabelCap + "; ");
				}
				result = GenText.TrimEndNewlines(stringBuilder.ToString());
			}
			return result;
		}

		// Token: 0x06000054 RID: 84 RVA: 0x00004234 File Offset: 0x00002434
		public override void Tick()
		{
			base.Tick();
			this.AdjustPowerNeed();
			if (!this.powerComp.PowerOn && this.soundSustainer != null && !this.soundSustainer.Ended)
			{
				this.soundSustainer.End();
			}
			if (this.flickableComp == null || (this.flickableComp != null && this.flickableComp.SwitchIsOn))
			{
				switch (this.ChamberStatus)
				{
				case ModdingStatus.Filling:
					this.handleFillingTick();
					return;
				case ModdingStatus.Modding:
					this.handleModdingTick();
					return;
				case ModdingStatus.Finished:
					this.handleFinalTick();
					return;
				default:
					if (this.soundSustainer != null && !this.soundSustainer.Ended)
					{
						this.soundSustainer.End();
					}
					break;
				}
			}
		}

		// Token: 0x06000055 RID: 85 RVA: 0x000042EC File Offset: 0x000024EC
		public void handleFillingTick()
		{
			if (this.powerComp.PowerOn && Current.Game.tickManager.TicksGame % 300 == 0)
			{
				FleckMaker.ThrowSmoke(base.Position.ToVector3(), base.Map, 1f);
			}
			IEnumerable<ThingOrderRequest> enumerable = this.orderProcessor.PendingRequests();
			bool flag = enumerable == null;
			if (!flag && enumerable.Count<ThingOrderRequest>() == 0)
			{
				flag = true;
			}
			if (flag)
			{
				this.ChamberStatus = ModdingStatus.Modding;
			}
		}

		// Token: 0x06000056 RID: 86 RVA: 0x00004364 File Offset: 0x00002564
		public void handleModdingTick()
		{
			if (this.powerComp.PowerOn)
			{
				if (Current.Game.tickManager.TicksGame % 100 == 0)
				{
					FleckMaker.ThrowSmoke(base.Position.ToVector3(), base.Map, 1.33f);
				}
				if (Current.Game.tickManager.TicksGame % 250 == 0)
				{
					for (int i = 0; i < 3; i++)
					{
						FleckMaker.ThrowMicroSparks(base.Position.ToVector3() + new Vector3((float)Rand.Range(-1, 1), 0f, (float)Rand.Range(-1, 1)), base.Map);
					}
				}
				if (this.soundSustainer == null || this.soundSustainer.Ended)
				{
					SoundDef craftingSound = this.conversionProperties.craftingSound;
					if (craftingSound != null && craftingSound.sustain)
					{
						SoundInfo soundInfo = SoundInfo.InMap(this, MaintenanceType.PerTick);
						this.soundSustainer = SoundStarter.TrySpawnSustainer(craftingSound, soundInfo);
					}
				}
				if (this.soundSustainer != null && !this.soundSustainer.Ended)
				{
					this.soundSustainer.Maintain();
				}
				this.nextResourceTick--;
				if (this.nextResourceTick <= 0)
				{
					this.nextResourceTick = this.conversionProperties.resourceTick;
					using (List<ThingOrderRequest>.Enumerator enumerator = this.orderProcessor.requestedItems.GetEnumerator())
					{
						while (enumerator.MoveNext())
						{
							ThingOrderRequest thingOrderRequest = enumerator.Current;
							if (thingOrderRequest.nutrition)
							{
								if (this.CountNutrition() > 0f)
								{
									Thing thing4 = this.ingredients.First((Thing thing) => thing.def.IsIngestible);
									if (thing4 != null)
									{
										int num = Math.Min((int)Math.Ceiling((double)thingOrderRequest.amount / ((double)this.tickToMod / (double)this.conversionProperties.resourceTick)), thing4.stackCount);
										Thing thing2 = null;
										Corpse corpse = thing4 as Corpse;
										if (corpse != null)
										{
											if (RottableUtility.IsDessicated(corpse))
											{
												this.ingredients.TryDrop(corpse, this.InteractionCell, base.Map, ThingPlaceMode.Near, 1, out thing2, null, null);
											}
											else
											{
												this.ingredients.TryDrop(corpse, this.InteractionCell, base.Map, ThingPlaceMode.Near, 1, out thing2, null, null);
												Pawn innerPawn = corpse.InnerPawn;
												if (innerPawn != null)
												{
													Pawn_EquipmentTracker equipment = innerPawn.equipment;
													if (equipment != null)
													{
														equipment.DropAllEquipment(this.InteractionCell, false);
													}
													Pawn_ApparelTracker apparel = innerPawn.apparel;
													if (apparel != null)
													{
														apparel.DropAll(this.InteractionCell, false, true);
													}
												}
												thing4.Destroy(0);
											}
										}
										else
										{
											this.ingredients.Take(thing4, num).Destroy(0);
										}
									}
								}
							}
							else if (this.ingredients.Any((Thing thing) => thing.def == thingOrderRequest.thingDef))
							{
								Thing thing3 = this.ingredients.First((Thing thing) => thing.def == thingOrderRequest.thingDef);
								if (thing3 != null)
								{
									int num2 = Math.Min((int)Math.Ceiling((double)(thingOrderRequest.amount / ((float)this.tickToMod / (float)this.conversionProperties.resourceTick))), thing3.stackCount);
									this.ingredients.Take(thing3, num2).Destroy(0);
								}
							}
						}
					}
				}
				if (this.remainingTickTracker > 0)
				{
					this.remainingTickTracker--;
					return;
				}
				this.ChamberStatus = ModdingStatus.Finished;
			}
		}

		// Token: 0x06000057 RID: 87 RVA: 0x00004700 File Offset: 0x00002900
		public void handleFinalTick()
		{
			this.ingredients.ClearAndDestroyContents(0);
			FilthMaker.TryMakeFilth(this.InteractionCell, base.Map, RimWorld.ThingDefOf.Filth_Slime, 5, 0);
			ChoiceLetter choiceLetter;
			if (this.IsPawnAndroid())
			{
				choiceLetter = LetterMaker.MakeLetter(TranslatorFormattedStringExtensions.Translate("AndroidConvertLetterLabel", this.currentPawn.Name.ToStringShort), TranslatorFormattedStringExtensions.Translate("AndroidConvertLetterDescription", this.currentPawn.Name.ToStringFull), LetterDefOf.PositiveEvent, this.currentPawn, null, null, null);
			}
			else
			{
				choiceLetter = LetterMaker.MakeLetter(TranslatorFormattedStringExtensions.Translate("AndroidModLetterLabel", this.currentPawn.Name.ToStringShort), TranslatorFormattedStringExtensions.Translate("AndroidModLetterDescription", this.currentPawn.Name.ToStringFull), LetterDefOf.PositiveEvent, this.currentPawn, null, null, null);
			}
			Find.LetterStack.ReceiveLetter(choiceLetter, null);
			this.CompleteConversion();
		}

		// Token: 0x06000058 RID: 88 RVA: 0x00004800 File Offset: 0x00002A00
		public float CountNutrition()
		{
			float num = 0f;
			foreach (Thing thing in this.ingredients)
			{
				Corpse corpse = thing as Corpse;
				if (corpse != null)
				{
					if (!RottableUtility.IsDessicated(corpse))
					{
						num += FoodUtility.GetBodyPartNutrition(corpse, corpse.InnerPawn.RaceProps.body.corePart);
					}
				}
				else if (thing.def.IsIngestible)
				{
					ThingDef def = thing.def;
					num += ((def != null) ? def.ingestible.CachedNutrition : 0.05f) * (float)thing.stackCount;
				}
			}
			return num;
		}

		// Token: 0x06000059 RID: 89 RVA: 0x000048BC File Offset: 0x00002ABC
		public string FormatIngredientCosts(out bool needsFulfilled, IEnumerable<ThingOrderRequest> requestedItems, bool deductCosts = true)
		{
			StringBuilder stringBuilder = new StringBuilder();
			needsFulfilled = true;
			foreach (ThingOrderRequest thingOrderRequest in requestedItems)
			{
				if (thingOrderRequest.nutrition)
				{
					float num = this.CountNutrition();
					if (deductCosts)
					{
						float num2 = thingOrderRequest.amount - num;
						if (num2 > 0f)
						{
							stringBuilder.Append(TranslatorFormattedStringExtensions.Translate("AndroidPrinterNeed", num2, Translator.Translate("AndroidNutrition")) + " ");
							needsFulfilled = false;
						}
					}
					else
					{
						stringBuilder.Append(TranslatorFormattedStringExtensions.Translate("AndroidPrinterNeed", thingOrderRequest.amount, Translator.Translate("AndroidNutrition")) + " ");
					}
				}
				else
				{
					int num3 = this.ingredients.TotalStackCountOfDef(thingOrderRequest.thingDef);
					if (deductCosts)
					{
						if ((float)num3 < thingOrderRequest.amount)
						{
							stringBuilder.Append(TranslatorFormattedStringExtensions.Translate("AndroidPrinterNeed", thingOrderRequest.amount - (float)num3, thingOrderRequest.thingDef.LabelCap) + " ");
							needsFulfilled = false;
						}
					}
					else
					{
						stringBuilder.Append(TranslatorFormattedStringExtensions.Translate("AndroidPrinterNeed", thingOrderRequest.amount, thingOrderRequest.thingDef.LabelCap) + " ");
					}
				}
			}
			return stringBuilder.ToString();
		}

		// Token: 0x1700000B RID: 11
		// (get) Token: 0x0600005A RID: 90 RVA: 0x00004A68 File Offset: 0x00002C68
		public Pawn currentPawn
		{
			get
			{
				return this.innerContainer.First<Thing>() as Pawn;
			}
		}

		// Token: 0x04000042 RID: 66
		protected bool contentsKnown;

		// Token: 0x04000043 RID: 67
		private CompPowerTrader _power;

		// Token: 0x04000044 RID: 68
		private CompPowerTrader powerComp;

		// Token: 0x04000045 RID: 69
		private CompFlickable flickableComp;

		// Token: 0x04000046 RID: 70
		public ThingOwner<Thing> ingredients = new ThingOwner<Thing>();

		// Token: 0x04000047 RID: 71
		public List<ModCommand> savedChanges = new List<ModCommand>();

		// Token: 0x04000048 RID: 72
		public ModdingStatus ChamberStatus;

		// Token: 0x04000049 RID: 73
		protected ThingOwner innerContainer;

		// Token: 0x0400004A RID: 74
		public ThingOrderProcessor orderProcessor;

		// Token: 0x0400004B RID: 75
		public int nextResourceTick;

		// Token: 0x0400004C RID: 76
		public int tickToMod;

		// Token: 0x0400004D RID: 77
		public int remainingTickTracker;

		// Token: 0x0400004E RID: 78
		private Sustainer soundSustainer;

		// Token: 0x0400004F RID: 79
		public StorageSettings inputSettings;

		// Token: 0x04000050 RID: 80
		public PawnConversionProperites conversionProperties;

		// Token: 0x04000051 RID: 81
		private Graphic cachedGraphicFull;
	}
}
