﻿using System;
using System.Collections.Generic;
using RimWorld;
using Verse;
using Verse.AI;

namespace AndroidConversion
{
	// Token: 0x0200000A RID: 10
	internal class JobDriver_FillConversionChamber : JobDriver
	{
		// Token: 0x17000004 RID: 4
		// (get) Token: 0x0600001B RID: 27 RVA: 0x000033E8 File Offset: 0x000015E8
		private Building_ConversionChamber conversionChamber
		{
			get
			{
				return (Building_ConversionChamber)((Thing)this.job.GetTarget(TargetIndex.B));
			}
		}

		// Token: 0x0600001C RID: 28 RVA: 0x00003400 File Offset: 0x00001600
		public override string GetReport()
		{
			Thing thing;
			if (this.pawn.carryTracker.CarriedThing != null)
			{
				thing = this.pawn.carryTracker.CarriedThing;
			}
			else
			{
				thing = base.TargetThingA;
			}
			return TranslatorFormattedStringExtensions.Translate("ReportHaulingTo", thing.LabelCap, this.job.targetB.Thing.LabelShort);
		}

		// Token: 0x0600001D RID: 29 RVA: 0x00003470 File Offset: 0x00001670
		public override bool TryMakePreToilReservations(bool errorOnFailed)
		{
			bool result;
			if (!ReservationUtility.CanReserve(this.pawn, base.TargetA, 1, -1, null, false))
			{
				result = false;
			}
			else if (!ReservationUtility.CanReserve(this.pawn, base.TargetB, 1, -1, null, false))
			{
				result = false;
			}
			else
			{
				ReservationUtility.Reserve(this.pawn, base.TargetA, this.job, 1, -1, null, errorOnFailed);
				ReservationUtility.Reserve(this.pawn, base.TargetB, this.job, 1, -1, null, errorOnFailed);
				result = true;
			}
			return result;
		}

		// Token: 0x0600001E RID: 30 RVA: 0x000034F4 File Offset: 0x000016F4
		protected override IEnumerable<Toil> MakeNewToils()
		{
			ToilFailConditions.FailOnDestroyedOrNull<JobDriver_FillConversionChamber>(this, TargetIndex.A);
			ToilFailConditions.FailOnDestroyedNullOrForbidden<JobDriver_FillConversionChamber>(this, TargetIndex.B);
			ToilFailConditions.FailOn<JobDriver_FillConversionChamber>(this, () => this.conversionChamber.ChamberStatus != ModdingStatus.Filling);
			yield return Toils_Reserve.Reserve(TargetIndex.A, 1, -1, null);
			yield return Toils_Reserve.ReserveQueue(TargetIndex.A, 1, -1, null);
			yield return Toils_Reserve.Reserve(TargetIndex.B, 1, -1, null);
			yield return Toils_Reserve.ReserveQueue(TargetIndex.B, 1, -1, null);
			Toil getToHaulTarget = ToilFailConditions.FailOnSomeonePhysicallyInteracting<Toil>(Toils_Goto.GotoThing(TargetIndex.A, PathEndMode.ClosestTouch), TargetIndex.A);
			yield return getToHaulTarget;
			yield return ToilFailConditions.FailOnSomeonePhysicallyInteracting<Toil>(Toils_Construct.UninstallIfMinifiable(TargetIndex.A), TargetIndex.A);
			yield return Toils_Haul.StartCarryThing(TargetIndex.A, false, true, false);
			yield return Toils_Haul.JumpIfAlsoCollectingNextTargetInQueue(getToHaulTarget, TargetIndex.A);
			Toil toil = Toils_Haul.CarryHauledThingToContainer();
			yield return toil;
			yield break;
		}

		// Token: 0x04000032 RID: 50
		private const TargetIndex CarryThingIndex = TargetIndex.A;

		// Token: 0x04000033 RID: 51
		private const TargetIndex DestIndex = TargetIndex.B;

    }
}
