﻿using System;
using System.Collections.Generic;
using Androids;
using RimWorld;
using Verse;
using Verse.AI;

namespace AndroidConversion
{
	// Token: 0x02000014 RID: 20
	internal class WorkGiver_ConversionChamber : WorkGiver_Scanner
	{
		// Token: 0x1700000C RID: 12
		// (get) Token: 0x0600005D RID: 93 RVA: 0x00004A8C File Offset: 0x00002C8C
		public override ThingRequest PotentialWorkThingRequest
		{
			get
			{
				return ThingRequest.ForDef(ThingDefOf.DekConversionChamber);
			}
		}

		// Token: 0x1700000D RID: 13
		// (get) Token: 0x0600005E RID: 94 RVA: 0x00004A98 File Offset: 0x00002C98
		public override PathEndMode PathEndMode
		{
			get
			{
				return PathEndMode.Touch;
			}
		}

		// Token: 0x0600005F RID: 95 RVA: 0x00004A9C File Offset: 0x00002C9C
		public override bool HasJobOnThing(Pawn pawn, Thing t, bool forced = false)
		{
			Building_ConversionChamber building_ConversionChamber = t as Building_ConversionChamber;
			bool result;
			if (building_ConversionChamber == null || building_ConversionChamber.ChamberStatus != ModdingStatus.Filling)
			{
				result = false;
			}
			else if (ForbidUtility.IsForbidden(t, pawn) || !ReservationUtility.CanReserveAndReach(pawn, t, PathEndMode.Touch, DangerUtility.NormalMaxDanger(pawn), 1, -1, null, forced))
			{
				result = false;
			}
			else if (pawn.Map.designationManager.DesignationOn(t, DesignationDefOf.Deconstruct) != null)
			{
				result = false;
			}
			else
			{
				IEnumerable<ThingOrderRequest> enumerable = building_ConversionChamber.orderProcessor.PendingRequests();
				bool flag = false;
				if (enumerable != null)
				{
					foreach (ThingOrderRequest request in enumerable)
					{
						if (this.FindIngredient(pawn, building_ConversionChamber, request) != null)
						{
							flag = true;
							break;
						}
					}
				}
				result = flag;
			}
			return result;
		}

		// Token: 0x06000060 RID: 96 RVA: 0x00004B6C File Offset: 0x00002D6C
		public override Job JobOnThing(Pawn pawn, Thing printerThing, bool forced = false)
		{
			Building_ConversionChamber building_ConversionChamber = printerThing as Building_ConversionChamber;
			IEnumerable<ThingOrderRequest> enumerable = building_ConversionChamber.orderProcessor.PendingRequests();
			if (enumerable != null)
			{
				foreach (ThingOrderRequest thingOrderRequest in enumerable)
				{
					Thing thing = this.FindIngredient(pawn, building_ConversionChamber, thingOrderRequest);
					if (thing != null)
					{
						if (!thingOrderRequest.nutrition)
						{
							return new Job(JobDefOf.DekFillConversionChamber, thing, printerThing)
							{
								count = (int)thingOrderRequest.amount
							};
						}
						int num = (int)Math.Ceiling((double)(thingOrderRequest.amount / thing.def.ingestible.CachedNutrition));
						if (num > 0)
						{
							return new Job(JobDefOf.DekFillConversionChamber, thing, printerThing)
							{
								count = num
							};
						}
					}
				}
			}
			return null;
		}

		// Token: 0x06000061 RID: 97 RVA: 0x00004C60 File Offset: 0x00002E60
		private Thing FindIngredient(Pawn pawn, Building_ConversionChamber androidPrinter, ThingOrderRequest request)
		{
			Thing result;
			if (request != null)
			{
				Predicate<Thing> extraPredicate = request.ExtraPredicate();
				Predicate<Thing> predicate = (Thing x) => !ForbidUtility.IsForbidden(x, pawn) && ReservationUtility.CanReserve(pawn, x, 1, -1, null, false) && extraPredicate(x);
				result = GenClosest.ClosestThingReachable(pawn.Position, pawn.Map, request.Request(), PathEndMode.ClosestTouch, TraverseParms.For(pawn, Danger.Deadly, 0, false, false, false), 9999f, predicate, null, 0, -1, false, RegionType.Normal, false);
			}
			else
			{
				result = null;
			}
			return result;
		}
	}
}
